@@ -19,7 +19,7 @@
 
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: acct.c,v 1.28 2001/12/26 14:58:31 gray Exp $";
+"@(#) $Id: acct.c,v 1.28.2.2 2002/05/30 14:06:15 gray Exp $";
 #endif
 #define LOG_EMPTY_USERNAME
 
@@ -341,12 +341,7 @@ rad_acct_system(radreq, dowtmp)
 	}
 #endif
 	
-	if (protocol == DV_FRAMED_PROTOCOL_PPP)
-		ut.proto = 'P';
-	else if (protocol == DV_FRAMED_PROTOCOL_SLIP)
-		ut.proto = 'S';
-	else
-		ut.proto = 'T';
+	ut.proto = protocol;
 	ut.time = t - ut.delay;
 
 	/* Process Accounting-On/Off records */
@@ -622,9 +617,13 @@ rad_accounting(radreq, activefd)
 #if defined(RT_ASCEND_EVENT_REQUEST) && defined(RT_ASCEND_EVENT_RESPONSE)
 	/* Special handling for Ascend-Event-Request */
 	if (radreq->code == RT_ASCEND_EVENT_REQUEST) {
+		VALUE_PAIR *reply = NULL;
+ 
 		write_detail(radreq, auth, "detail");
+		avl_move_attr(&reply, &radreq->request, DA_PROXY_STATE); 
 		rad_send_reply(RT_ASCEND_EVENT_RESPONSE,
 			       radreq, NULL, NULL, activefd);
+		avl_move_attr(&radreq->request, &reply, DA_PROXY_STATE);
 		stat_inc(acct, radreq->ipaddr, num_resp);
 		return 0;
 	}
@@ -633,9 +632,11 @@ rad_accounting(radreq, activefd)
 	if (rad_acct_system(radreq, doradwtmp) == 0 &&
 	    rad_acct_db(radreq, auth) == 0 &&
 	    rad_acct_ext(radreq) == 0) {
-		/* Now send back an ACK to the NAS. */
+		VALUE_PAIR *reply = NULL;
+		avl_move_attr(&reply, &radreq->request, DA_PROXY_STATE);
 		rad_send_reply(RT_ACCOUNTING_RESPONSE,
 			       radreq, NULL, NULL, activefd);
+		avl_move_attr(&radreq->request, &reply, DA_PROXY_STATE);
 		stat_inc(acct, radreq->ipaddr, num_resp);
 		return 0;
 	}
@@ -829,13 +830,14 @@ rad_check_multi(name, request, maxsimul, pcount)
 		    && up->type == P_LOGIN) {
 			if (rad_check_ts(up) == 1) {
 				count++;
-				/*
-				 *	Does it look like a MPP attempt?
-				 */
-				if (strchr("SCPA", up->proto)
-				    && ipno
-				    && up->framed_address == ipno)
+				/* Does it look like a MPP attempt? */
+				if (ipno && up->framed_address == ipno)
+					switch (up->proto) {
+					case DV_FRAMED_PROTOCOL_PPP:
+					case DV_FRAMED_PROTOCOL_SLIP:
+					case 256: /* Ascend MPP */
 					mpp = 1;
+					}
 			} else {
 				/* Hung record */
 				up->type = P_IDLE;
