@@ -18,7 +18,7 @@
 #define RADIUS_MODULE_AUTH_C
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: auth.c,v 1.47.2.1 2002/03/19 15:10:18 gray Exp $";
+"@(#) $Id: auth.c,v 1.47.2.2 2002/05/30 14:06:41 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -256,19 +256,19 @@ rad_check_password(radreq, check_item, namepair, user_msg, userpass)
 	/* Find the password sent by the user. If it's not present,
 	   authentication fails. */
 	
-	if (!(auth_item = avl_find(radreq->request, DA_CHAP_PASSWORD))) {
+	if (auth_item = avl_find(radreq->request, DA_CHAP_PASSWORD))
+		auth_type = DV_AUTH_TYPE_LOCAL;
+	else
 		auth_item = avl_find(radreq->request, DA_PASSWORD);
-		/* Decrypt the password. */
-		if (auth_item) {
-			if (auth_item->strlength == 0)
-				userpass[0] = 0;
-			else
-				req_decrypt_password(userpass, radreq,
-						     auth_item);
-		}
-	}
-		
-	if (auth_item == NULL)
+	
+	/* Decrypt the password. */
+	if (auth_item) {
+		if (auth_item->strlength == 0)
+			userpass[0] = 0;
+		else
+			req_decrypt_password(userpass, radreq,
+					     auth_item);
+	} else /* if (auth_item == NULL) */
 		return AUTH_FAIL;
 	
 	/* Set up authentication data */
