@@ -1,5 +1,5 @@
 
-/*  A Bison parser, made from /home/gray/gnu-radius/radiusd/./config.y
+/*  A Bison parser, made from /home/gray/radius-0.96-series/radiusd/./config.y
  by  GNU Bison version 1.27
   */
 
@@ -84,7 +84,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-	"@(#) $Id: config.y,v 1.30 2001/12/26 14:49:49 gray Exp $";
+	"@(#) $Id: config.y,v 1.30.2.1 2002/03/19 15:10:18 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -1365,26 +1365,26 @@ case 59:
 case 60:
 #line 380 "config.y"
 {
-			  asgn(&request_class[R_AUTH].spawn, &ccvsp[0].value, AT_BOOL, 0);
+			  asgn(&request_class[R_ACCT].spawn, &ccvsp[0].value, AT_BOOL, 0);
 		  ;
     break;}
 case 61:
 #line 384 "config.y"
 {
-			  asgn(&request_class[R_AUTH].ttl, &ccvsp[0].value, AT_INT, 0);
+			  asgn(&request_class[R_ACCT].ttl, &ccvsp[0].value, AT_INT, 0);
 		  ;
     break;}
 case 62:
 #line 388 "config.y"
 {
-			  asgn(&request_class[R_AUTH].max_requests, &ccvsp[0].value,
+			  asgn(&request_class[R_ACCT].max_requests, &ccvsp[0].value,
 			       AT_INT, 0);
 		  ;
     break;}
 case 63:
 #line 393 "config.y"
 {
-			  asgn(&request_class[R_AUTH].cleanup_delay, &ccvsp[0].value,
+			  asgn(&request_class[R_ACCT].cleanup_delay, &ccvsp[0].value,
 			       AT_INT, 0);
 		  ;
     break;}
