@@ -1,26 +1,24 @@
 /* This file is part of GNU RADIUS.
- * Copyright (C) 2000, Sergey Poznyakoff
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- */
+   Copyright (C) 2000, Sergey Poznyakoff
+  
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+  
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+  
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
-#define RADIUS_MODULE 13
+#define RADIUS_MODULE_RADIUS_C
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: radius.c,v 1.8 2001/03/25 13:14:51 gray Exp $";
+"@(#) $Id: radius.c,v 1.20 2001/12/19 14:05:08 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -45,6 +43,7 @@ static char rcsid[] =
  *	Make sure our buffer is aligned.
  */
 static int	i_send_buffer[RAD_BUFFER_SIZE];
+#define SEND_BUFFER_SIZE sizeof(i_send_buffer)
 static char	*send_buffer = (char *)i_send_buffer;
 
 /*
@@ -52,9 +51,9 @@ static char	*send_buffer = (char *)i_send_buffer;
  *	reply attribute value pairs and any user message provided.
  */
 int
-rad_send_reply(code, authreq, oreply, msg, activefd)
+rad_send_reply(code, radreq, oreply, msg, activefd)
 	int code;
-	AUTH_REQ *authreq;
+	RADIUS_REQ *radreq;
 	VALUE_PAIR *oreply;
 	char *msg;
 	int activefd;
@@ -76,25 +75,25 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 	reply = oreply;
 
 	switch (code) {
-		case PW_PASSWORD_REJECT:
-		case PW_AUTHENTICATION_REJECT:
+		case RT_PASSWORD_REJECT:
+		case RT_AUTHENTICATION_REJECT:
 			what = _("Reject");
 			/*
 			 *	Also delete all reply attributes
 			 *	except proxy-pair and port-message.
 			 */
 			reply = NULL;
-			pairmove2(&reply, &oreply, DA_REPLY_MESSAGE);
-			pairmove2(&reply, &oreply, DA_PROXY_STATE);
+			avl_move_attr(&reply, &oreply, DA_REPLY_MESSAGE);
+			avl_move_attr(&reply, &oreply, DA_PROXY_STATE);
 			break;
-		case PW_ACCESS_CHALLENGE:
+		case RT_ACCESS_CHALLENGE:
 			what = _("Challenge");
-			stat_inc(auth, authreq->ipaddr, num_challenges);
+			stat_inc(auth, radreq->ipaddr, num_challenges);
 			break;
-		case PW_AUTHENTICATION_ACK:
+		case RT_AUTHENTICATION_ACK:
 			what = _("Ack");
 			break;
-		case PW_ACCOUNTING_RESPONSE:
+		case RT_ACCOUNTING_RESPONSE:
 			what = _("Accounting Ack");
 			break;
 		default:
@@ -106,12 +105,12 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 	 *	Build standard header
 	 */
 	auth->code = code;
-	auth->id = authreq->id;
-	memcpy(auth->vector, authreq->vector, AUTH_VECTOR_LEN);
+	auth->id = radreq->id;
+	memcpy(auth->vector, radreq->vector, AUTH_VECTOR_LEN);
 
 	debug(1, ("Sending %s of id %d to %lx (nas %s)",
-		what, authreq->id, (u_long)authreq->ipaddr,
-		nas_name2(authreq)));
+		what, radreq->id, (u_long)radreq->ipaddr,
+		nas_request_to_name(radreq)));
 
 	total_length = AUTH_HDR_LEN;
 
@@ -119,9 +118,8 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 	 *	Load up the configuration values for the user
 	 */
 	ptr = auth->data;
-	while (reply != (VALUE_PAIR *)NULL) {
-		if (debug_on(10))
-			debug_pair("reply", reply);
+	while (reply) {
+		debug(10, ("reply: %s", format_pair(reply)));
 
 		/*
 		 *	This could be a vendor-specific attribute.
@@ -129,7 +127,7 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 		length_ptr = NULL;
 		if ((vendorcode = VENDOR(reply->attribute)) > 0 &&
 		    (vendorpec  = vendor_id_to_pec(vendorcode)) > 0) {
-			if (total_length + 6 >= RAD_BUFFER_SIZE)
+			if (total_length + 6 >= SEND_BUFFER_SIZE)
 				goto err;
 			*ptr++ = DA_VENDOR_SPECIFIC;
 			length_ptr = ptr;
@@ -151,7 +149,7 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 
 		switch(reply->type) {
 
-		case PW_TYPE_STRING:
+		case TYPE_STRING:
 			/*
 			 *	FIXME: this is just to make sure but
 			 *	should NOT be needed. In fact I have no
@@ -164,7 +162,7 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 			if (len >= AUTH_STRING_LEN) {
 				len = AUTH_STRING_LEN - 1;
 			}
-			if (total_length + len + 2 >= RAD_BUFFER_SIZE)
+			if (total_length + len + 2 >= SEND_BUFFER_SIZE)
 				goto err;
 
 			*ptr++ = len + 2;
@@ -174,9 +172,9 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 			total_length += len + 2;
 			break;
 
-		case PW_TYPE_INTEGER:
-		case PW_TYPE_IPADDR:
-			if (total_length + sizeof(UINT4) + 2 >= RAD_BUFFER_SIZE)
+		case TYPE_INTEGER:
+		case TYPE_IPADDR:
+			if (total_length + sizeof(UINT4) + 2 >= SEND_BUFFER_SIZE)
 				goto err;
 				
 			*ptr++ = sizeof(UINT4) + 2;
@@ -209,7 +207,7 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 				block_len = len;
 			}
 
-			if (total_length + block_len + 2 >= RAD_BUFFER_SIZE) {
+			if (total_length + block_len + 2 >= SEND_BUFFER_SIZE) {
 				radlog(L_ERR,
 				       _("user message too long in rad_send_reply"));
 				return -1; /* be on the safe side */
@@ -227,11 +225,11 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 
 	auth->length = htons(total_length);
 
-	/*
-	 *	Append secret and calculate the response digest
-	 */
-	secretlen = strlen(authreq->secret);
-	memcpy(send_buffer + total_length, authreq->secret, secretlen);
+	/* Append secret and calculate the response digest */
+	secretlen = strlen(radreq->secret);
+	if (total_length + secretlen >= SEND_BUFFER_SIZE)
+	    goto err;
+	memcpy(send_buffer + total_length, radreq->secret, secretlen);
 	md5_calc(digest, (u_char *)auth, total_length + secretlen);
 	memcpy(auth->vector, digest, AUTH_VECTOR_LEN);
 	memset(send_buffer + total_length, 0, secretlen);
@@ -239,8 +237,8 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 	sin = (struct sockaddr_in *) &saremote;
         memset ((char *) sin, '\0', sizeof (saremote));
 	sin->sin_family = AF_INET;
-	sin->sin_addr.s_addr = htonl(authreq->ipaddr);
-	sin->sin_port = htons(authreq->udp_port);
+	sin->sin_addr.s_addr = htonl(radreq->ipaddr);
+	sin->sin_port = htons(radreq->udp_port);
 
 	/*
 	 *	Send it to the user
@@ -252,8 +250,8 @@ rad_send_reply(code, authreq, oreply, msg, activefd)
 	 *	Just to be tidy move pairs back.
 	 */
 	if (reply != oreply) {
-		pairmove2(&oreply, &reply, DA_PROXY_STATE);
-		pairmove2(&oreply, &reply, DA_REPLY_MESSAGE);
+		avl_move_attr(&oreply, &reply, DA_PROXY_STATE);
+		avl_move_attr(&oreply, &reply, DA_REPLY_MESSAGE);
 	}
 
 	return 0;
@@ -263,40 +261,23 @@ err:
 }
 
 
-/*
- *	Validates the requesting client NAS.  Calculates the
- *	digest to be used for decrypting the users password
- *	based on the clients private key.
- */
+/* Validates the requesting client NAS. */
 int
-calc_digest(digest, authreq)
-	u_char *digest;
-	AUTH_REQ *authreq;
+validate_client(radreq)
+	RADIUS_REQ *radreq;
 {
-	u_char	buffer[128];
-	int	secretlen;
 	CLIENT	*cl;
 
-	/*
-	 *	See if we know this client.
-	 */
-	if ((cl = client_find(authreq->ipaddr)) == NULL) {
+	if ((cl = client_lookup_ip(radreq->ipaddr)) == NULL) {
 		radlog(L_ERR, _("request from unknown client: %s"),
-			client_name(authreq->ipaddr));
+			client_lookup_name(radreq->ipaddr));
 		return -1;
 	}
 
-	/*
-	 *	Use the secret to setup the decryption digest
-	 */
-	secretlen = strlen(cl->secret);
-	strcpy(buffer, cl->secret);
-	memcpy(buffer + secretlen, authreq->vector, AUTH_VECTOR_LEN);
-	md5_calc(digest, buffer, secretlen + AUTH_VECTOR_LEN);
-	strcpy(authreq->secret, cl->secret);
-	memset(buffer, 0, sizeof(buffer));
+	/* Save the secret key */
+	radreq->secret = cl->secret;
 
-	return(0);
+	return 0;
 }
 
 /*
@@ -304,54 +285,39 @@ calc_digest(digest, authreq)
  *	signature based on the clients private key.
  */
 int
-calc_acctdigest(digest, authreq)
-	u_char *digest;
-	AUTH_REQ *authreq;
+calc_acctdigest(radreq)
+	RADIUS_REQ *radreq;
 {
 	int	secretlen;
-	CLIENT	*cl;
 	char zero[AUTH_VECTOR_LEN];
-	u_char	* recvbuf = (u_char*) authreq->data;
-	int	len = authreq->data_len;
+	u_char	*recvbuf;
+	int	len = radreq->data_len;
+	u_char digest[AUTH_VECTOR_LEN];
 
-	/*
-	 *	See if we know this client.
-	 */
-	if ((cl = client_find(authreq->ipaddr)) == NULL) {
-		radlog(L_ERR, _("request from unknown client: %s"),
-			client_name(authreq->ipaddr));
-		return -1;
-	}
+	secretlen = strlen(radreq->secret);
 
-	/*
-	 *	Copy secret into authreq->secret so that we can
-	 *	use it with send_acct_reply()
-	 */
-	secretlen = strlen(cl->secret);
-	strcpy(authreq->secret, cl->secret);
-
-	/*
-	 *	Older clients have the authentication vector set to
-	 *	all zeros. Return `1' in that case.
-	 */
+	recvbuf = emalloc(len + secretlen);
+	memcpy(recvbuf, radreq->data, len + secretlen);
+	
+	/* Older clients have the authentication vector set to
+	   all zeros. Return `1' in that case. */
 	memset(zero, 0, sizeof(zero));
-	if (memcmp(authreq->vector, zero, AUTH_VECTOR_LEN) == 0)
+	if (memcmp(radreq->vector, zero, AUTH_VECTOR_LEN) == 0)
 		return 1;
 
-	/*
-	 *	Zero out the auth_vector in the received packet.
-	 *	Then append the shared secret to the received packet,
-	 *	and calculate the MD5 sum. This must be the same
-	 *	as the original MD5 sum (authreq->vector).
-	 */
+	/* Zero out the auth_vector in the received packet.
+	   Then append the shared secret to the received packet,
+	   and calculate the MD5 sum. This must be the same
+	   as the original MD5 sum (radreq->vector). */
 	memset(recvbuf + 4, 0, AUTH_VECTOR_LEN);
-	memcpy(recvbuf + len, cl->secret, secretlen);
+	memcpy(recvbuf + len, radreq->secret, secretlen);
 	md5_calc(digest, recvbuf, len + secretlen);
-
+	efree(recvbuf);
+	
 	/*
 	 *	Return 0 if OK, 2 if not OK.
 	 */
-	return memcmp(digest, authreq->vector, AUTH_VECTOR_LEN) ? 2 : 0;
+	return memcmp(digest, radreq->vector, AUTH_VECTOR_LEN) ? 2 : 0;
 }
 
 /*
@@ -359,7 +325,7 @@ calc_acctdigest(digest, authreq)
  *	structure, and attach attribute-value pairs contained in
  *	the request to the new structure.
  */
-AUTH_REQ *
+RADIUS_REQ *
 radrecv(host, udp_port, buffer, length)
 	UINT4 host;
 	u_short udp_port;
@@ -368,9 +334,9 @@ radrecv(host, udp_port, buffer, length)
 {
 	u_char		*ptr;
 	AUTH_HDR	*auth;
-	int		totallen;
-	int		attribute;
-	int		attrlen;
+	unsigned	totallen;
+	unsigned	attribute;
+	unsigned	attrlen;
  	DICT_ATTR	*attr;
 	UINT4		lval;
 	UINT4		vendorcode;
@@ -378,15 +344,15 @@ radrecv(host, udp_port, buffer, length)
 	VALUE_PAIR	*first_pair;
 	VALUE_PAIR	*prev;
 	VALUE_PAIR	*pair;
-	AUTH_REQ	*authreq;
+	RADIUS_REQ	*radreq;
 
 	/*
 	 *	Pre-allocate the new request data structure
 	 */
 
-	authreq = alloc_request();
+	radreq = radreq_alloc();
 	
-	memset(authreq, 0, sizeof(AUTH_REQ));
+	memset(radreq, 0, sizeof(RADIUS_REQ));
 
 	auth = (AUTH_HDR *)buffer;
 	totallen = ntohs(auth->length);
@@ -403,21 +369,21 @@ radrecv(host, udp_port, buffer, length)
 	/*
 	 *	Fill header fields
 	 */
-	authreq->ipaddr = host;
-	authreq->udp_port = udp_port;
-	authreq->id = auth->id;
-	authreq->code = auth->code;
-	memcpy(authreq->vector, auth->vector, AUTH_VECTOR_LEN);
-	authreq->data = buffer;
-	authreq->data_len = length;
+	radreq->ipaddr = host;
+	radreq->udp_port = udp_port;
+	radreq->id = auth->id;
+	radreq->code = auth->code;
+	memcpy(radreq->vector, auth->vector, AUTH_VECTOR_LEN);
+	radreq->data = buffer;
+	radreq->data_len = length;
 
 	/*
 	 *	Extract attribute-value pairs
 	 */
 	ptr = auth->data;
 	length -= AUTH_HDR_LEN;
-	first_pair = (VALUE_PAIR *)NULL;
-	prev = (VALUE_PAIR *)NULL;
+	first_pair = NULL;
+	prev = NULL;
 
 	while (length > 0) {
 
@@ -447,7 +413,7 @@ radrecv(host, udp_port, buffer, length)
 			}
 		}
 
-		if ((attr = attr_number_to_dict(attribute)) == (DICT_ATTR *)NULL) {
+		if ((attr = attr_number_to_dict(attribute)) == NULL) {
 			debug(1, ("Received unknown attribute %d", attribute));
 		} else if ( attrlen >= AUTH_STRING_LEN ) {
 			debug(1, ("attribute %d too long, %d >= %d", attribute,
@@ -457,55 +423,50 @@ radrecv(host, udp_port, buffer, length)
 			      ("attribute %d longer then buffer left, %d > %d",
 				attribute, attrlen, length));
 		} else {
-			pair = alloc_pair();
+			pair = avp_alloc();
 			
 			pair->name = attr->name;
 			pair->attribute = attr->value;
 			pair->type = attr->type;
-			pair->next = (VALUE_PAIR *)NULL;
+			pair->prop = attr->prop;
+			pair->next = NULL;
 
 			switch (attr->type) {
 
-			case PW_TYPE_STRING:
+			case TYPE_STRING:
 				/* attrlen always < AUTH_STRING_LEN */
 				pair->strlength = attrlen;
 				pair->strvalue = alloc_string(attrlen + 1);
 				memcpy(pair->strvalue, ptr, attrlen);
 				pair->strvalue[attrlen] = 0;
 
-				if (debug_on(10)) 
-					debug_pair("recv", pair);
+				debug(10, ("recv: %s", format_pair(pair)));
 
-				if (first_pair == (VALUE_PAIR *)NULL) {
+				if (first_pair == NULL) 
 					first_pair = pair;
-				}
-				else {
+				else 
 					prev->next = pair;
-				}
 				prev = pair;
 				break;
 			
-			case PW_TYPE_INTEGER:
-			case PW_TYPE_IPADDR:
+			case TYPE_INTEGER:
+			case TYPE_IPADDR:
 				memcpy(&lval, ptr, sizeof(UINT4));
 				pair->lvalue = ntohl(lval);
 
-				if (debug_on(10)) 
-					debug_pair("recv", pair);
+				debug(10, ("recv: %s", format_pair(pair)));
 
-				if (first_pair == (VALUE_PAIR *)NULL) {
+				if (first_pair == NULL) 
 					first_pair = pair;
-				}
-				else {
+				else 
 					prev->next = pair;
-				}
 				prev = pair;
 				break;
 			
 			default:
 				debug(1, ("    %s (Unknown Type %d)",
 					attr->name,attr->type));
-				free_pair(pair);
+				avp_free(pair);
 				break;
 			}
 
@@ -513,8 +474,8 @@ radrecv(host, udp_port, buffer, length)
 		ptr += attrlen;
 		length -= attrlen;
 	}
-	authreq->request = first_pair;
-	return(authreq);
+	radreq->request = first_pair;
+	return(radreq);
 }
 
 #ifdef USE_LIVINGSTON_MENUS
@@ -523,8 +484,8 @@ radrecv(host, udp_port, buffer, length)
  *	any user message provided and a state value.
  */
 void
-send_challenge(authreq, msg, state, activefd)
-	AUTH_REQ *authreq;
+send_challenge(radreq, msg, state, activefd)
+	RADIUS_REQ *radreq;
 	char *msg;
 	char *state;
 	int activefd;
@@ -544,9 +505,9 @@ send_challenge(authreq, msg, state, activefd)
 	/*
 	 *	Build standard response header
 	 */
-	auth->code = PW_ACCESS_CHALLENGE;
-	auth->id = authreq->id;
-	memcpy(auth->vector, authreq->vector, AUTH_VECTOR_LEN);
+	auth->code = RT_ACCESS_CHALLENGE;
+	auth->id = radreq->id;
+	memcpy(auth->vector, radreq->vector, AUTH_VECTOR_LEN);
 	total_length = AUTH_HDR_LEN;
 	ptr = auth->data;
 
@@ -561,7 +522,7 @@ send_challenge(authreq, msg, state, activefd)
 				block_len = len;
 			}
 
-			if (total_length + block_len + 2 >= RAD_BUFFER_SIZE) {
+			if (total_length + block_len + 2 >= SEND_BUFFER_SIZE) {
 				radlog(L_ERR,
 				    _("user message too long in send_challenge"));
 				return;
@@ -580,7 +541,7 @@ send_challenge(authreq, msg, state, activefd)
 	/*
 	 *	Append the state info
 	 */
-	if ((state != (char *)NULL) && (strlen(state) > 0)) {
+	if ((state != NULL) && (strlen(state) > 0)) {
 		len = strlen(state);
 		*ptr++ = DA_STATE;
 		*ptr++ = len + 2;
@@ -594,11 +555,14 @@ send_challenge(authreq, msg, state, activefd)
 	 */
 	auth->length = htons(total_length);
 
-	/*
-	 *	Calculate the response digest
-	 */
-	secretlen = strlen(authreq->secret);
-	memcpy(send_buffer + total_length, authreq->secret, secretlen);
+	/* Calculate the response digest */
+	secretlen = strlen(radreq->secret);
+	if (total_length + secretlen >= SEND_BUFFER_SIZE) {
+		radlog(L_ERR,
+		       _("send buffer overflow in send_challenge"));
+		return;
+	}
+	memcpy(send_buffer + total_length, radreq->secret, secretlen);
 	md5_calc(digest, (u_char *)auth, total_length + secretlen);
 	memcpy(auth->vector, digest, AUTH_VECTOR_LEN);
 	memset(send_buffer + total_length, 0, secretlen);
@@ -606,14 +570,14 @@ send_challenge(authreq, msg, state, activefd)
 	sin = (struct sockaddr_in *) &saremote;
         memset ((char *) sin, '\0', sizeof (saremote));
 	sin->sin_family = AF_INET;
-	sin->sin_addr.s_addr = htonl(authreq->ipaddr);
-	sin->sin_port = htons(authreq->udp_port);
+	sin->sin_addr.s_addr = htonl(radreq->ipaddr);
+	sin->sin_port = htons(radreq->udp_port);
 
 	debug(1, ("Sending Challenge of id %d to %lx (nas %s)",
-		authreq->id, (u_long)authreq->ipaddr,
-		nas_name2(authreq)));
+		radreq->id, (u_long)radreq->ipaddr,
+		nas_request_to_name(radreq)));
 	
-	stat_inc(auth, authreq->ipaddr, num_challenges);
+	stat_inc(auth, radreq->ipaddr, num_challenges);
 	
 	/*
 	 *	Send it to the user
