@@ -15,7 +15,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
-/* $Id: version.c,v 1.16 2001/12/20 16:53:56 gray Exp $ */
+/* $Id: version.c,v 1.16.2.1 2002/06/05 11:40:45 gray Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -112,15 +112,6 @@ static char *compile_flag_str[] = {
 #endif
 #if defined(OSFC2)
 	"OSFC2",
-#endif
-#if defined(NT_DOMAIN_HACK)
-	"NT_DOMAIN_HACK",
-#endif
-#if defined(SPECIALIX_JETSTREAM_HACK)
-	"SPECIALIX_JETSTREAM_HACK",
-#endif
-#if defined(ASCEND_PORT_HACK)
-	"ASCEND_PORT_HACK",
 #endif
 	NULL
 };
