@@ -17,7 +17,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: dict.c,v 1.19 2001/12/19 14:04:00 gray Exp $";
+"$Id: dict.c,v 1.19.2.1 2002/05/30 14:02:21 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -159,6 +159,37 @@ static struct keyword type_kw[] = {
 	"date", TYPE_DATE
 };
 
+typedef struct attr_parser_tab ATTR_PARSER_TAB;
+struct attr_parser_tab {
+	ATTR_PARSER_TAB *next;
+	int attr;
+	attr_parser_fp fun;
+};
+static ATTR_PARSER_TAB *attr_parser_tab;
+static attr_parser_fp dict_find_parser(int);
+
+attr_parser_fp
+dict_find_parser(attr)
+{
+	ATTR_PARSER_TAB *ep;
+	for (ep = attr_parser_tab; ep; ep = ep->next)
+		if (ep->attr == attr)
+			return ep->fun;
+	return NULL;
+}
+
+void
+dict_register_parser(attr, fun)
+	int attr;
+	attr_parser_fp fun;
+{
+	ATTR_PARSER_TAB *e = alloc_entry(sizeof(*e));
+	e->attr = attr;
+	e->fun = fun;
+	e->next = attr_parser_tab;
+	attr_parser_tab = e;
+}
+
 /*ARGSUSED*/
 int
 _dict_include(errcnt, fc, fv, file, lineno)
@@ -244,6 +275,7 @@ _dict_attribute(errcnt, fc, fv, file, lineno)
 	char *p;
 	int flags = AF_DEFAULT_FLAGS;
 	int prop  = AP_DEFAULT_ADD;
+	attr_parser_fp fp = NULL;
 	
 	if (nfields(fc, 4, 6, file, lineno))
 		return 0;
@@ -260,11 +292,21 @@ _dict_attribute(errcnt, fc, fv, file, lineno)
 		return 0;
 	}
 
-	if ((type = xlat_keyword(type_kw, ATTR_TYPE, TYPE_INVALID)) ==
-	    TYPE_INVALID) {
+	if (strcmp(ATTR_TYPE, "abinary") == 0) {
+		type = TYPE_STRING;
+		fp = dict_find_parser(value);
+		if (!fp) {
+			radlog(L_WARN,
+		       _("%s:%d: no parser registered for this attribute"),
+			       file, lineno);
+			return 0;
+		}
+	} else
+		type = xlat_keyword(type_kw, ATTR_TYPE, TYPE_INVALID);
+	
+	if (type == TYPE_INVALID) {
 		radlog(L_ERR,
-		       _("%s:%d: invalid type"),
-		       file, lineno);
+		       _("%s:%d: invalid type"), file, lineno);
 		(*errcnt)++;
 		return 0;
 	}
@@ -334,6 +376,7 @@ _dict_attribute(errcnt, fc, fv, file, lineno)
 	attr->value = value;
 	attr->type = type;
 	attr->prop = flags|prop;
+	attr->parser = fp;
 	if (vendor)
 		attr->value |= (vendor << 16);
 	
@@ -476,6 +519,11 @@ parse_dict(name)
 int
 dict_init()
 {
+	if (!attr_parser_tab) {
+		/* Register ascend filters */
+		dict_register_parser(242, ascend_parse_filter);
+		dict_register_parser(243, ascend_parse_filter);
+	}
 	dict_free();
 	return parse_dict(RADIUS_DICTIONARY);
 }
