@@ -1,5 +1,5 @@
 
-/*  A Bison parser, made from /home/gray/radius-0.96/radlib/users.y
+/*  A Bison parser, made from /home/gray/radius-0.96-series/radlib/./users.y
  by  GNU Bison version 1.27
   */
 
@@ -37,7 +37,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: users.y,v 1.17 2001/11/29 15:54:32 gray Exp $";
+"$Id: users.y,v 1.17.2.1 2002/05/30 14:02:50 gray Exp $";
 #endif
 
 #if defined(HAVE_CONFIG_H)
@@ -83,10 +83,6 @@ typedef union {
 	VALUE_PAIR *pair;
 	int op;
 } YYSTYPE;
-#ifndef YYDEBUG
-#define YYDEBUG 1
-#endif
-
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -1143,8 +1139,18 @@ install_pair(name, op, valstr)
 				return NULL;
 			}
 		}
+
 		pair->strvalue = make_string(valstr);
 		pair->strlength = strlen(pair->strvalue);
+
+		if (attr->parser && attr->parser(pair, &s)) {
+			radlog(L_ERR, "%s:%d: attribute %s: %s",
+			       source_filename, source_line_num,
+			       pair->name, s);
+			free(s);
+			avp_free(pair);
+			return NULL;
+		}
 		break;
 
 	case TYPE_INTEGER:
@@ -1279,3 +1285,4 @@ enable_usr_dbg(val)
 	    source_filename, source_line_num);
 #endif
 }
+
