@@ -17,7 +17,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: util.c,v 1.21 2001/12/21 22:19:19 gray Exp $";
+"$Id: util.c,v 1.21.2.1 2002/05/30 14:04:07 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -326,7 +326,7 @@ format_string_visual(buf, runlen, str, len)
 				seg = NULL;
 			}
 			if (buf) {
-				sprintf(buf, "\\%03o", *ptr);
+				sprintf(buf, "\\%03o", *(u_char*)ptr);
 				buf += 4;
 			}
 			outbytes += 4;
