@@ -1,11 +1,10 @@
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
 #endif
-#if defined(HAVE_GETOPT_LONG)
-# include <getopt.h>
-#endif
+
+#include <getopt1.h>
 #include <libguile.h>
-#include <radiusd.h>
+#include <radius.h>
 
 
 static void radscm_shell(void *closure, int argc, char **argv);
