@@ -17,7 +17,7 @@
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: radwho.c,v 1.11 2001/11/27 12:13:36 gray Exp $";
+"$Id: radwho.c,v 1.11.2.1 2002/04/11 12:01:44 gray Exp $";
 #endif
 
 #if defined(HAVE_CONFIG_H)
@@ -59,7 +59,6 @@ void format_date(char *buf, FORMAT *fmt, struct radutmp *up);
 void format_porttype(char *buf, FORMAT *fmt, struct radutmp *up);
 void format_port(char *buf, FORMAT *fmt, struct radutmp *up);
 void format_nas(char *buf, FORMAT *fmt, struct radutmp *up);
-void format_proto(char *buf, FORMAT *fmt, struct radutmp *up);
 void format_address(char *buf, FORMAT *fmt, struct radutmp *up);
 void format_orig(char *buf, FORMAT *fmt, struct radutmp *ut);
 void format_sid(char *buf, FORMAT *fmt, struct radutmp *ut);
@@ -227,6 +226,8 @@ struct option longopt[] = {
 #define SD_FULL      1
 #define SD_ABBR      2
 
+#define P_CONSOLE -1  /* Special radutmp type value for local users */
+
 int  fingerd;             /* Are we run as fingerd */
 int  secure;              /* Secure mode: do not answer queries w/o username */
 int  showlocal;           /* Display local users as well */
@@ -365,19 +366,18 @@ main(argc, argv)
 	if (!filename)
 		filename = radutmp_path;
 	
-	/*
-	 *	Read the "naslist" file.
-	 */
+	/* Read the dictionary files */
+	dict_init();
+        /* Read the "naslist" file. */
 	path = mkfilename(radius_dir, RADIUS_NASLIST);
 	if ((naslist = my_read_naslist_file(path)) == NULL)
 		exit(1);
 	efree(path);
-
+	/* Read realms */
 	path = mkfilename(radius_dir, RADIUS_REALMS);
 	my_read_realms(path);
 	efree(path);
 	
-
 	/*
 	 *	See if we are "fingerd".
 	 */
@@ -752,7 +752,12 @@ format_proto(buf, fmt, up)
 	FORMAT         *fmt;
 	struct radutmp *up;
 {
-	strcpy(buf, proto(up));
+	DICT_VALUE *dval = value_lookup(up->proto, "Framed-Protocol");
+	
+	if (!dval)
+		snprintf(buf, fmt->width, "%lu", up->proto);
+	else
+		snprintf(buf, fmt->width, "%s", dval->name);
 }	
 
 /*ARGSUSED*/
@@ -826,21 +831,6 @@ time_str(buffer, t)
 	return buffer;
 }
 
-char *
-proto(rt)
-	struct radutmp *rt;
-{
-	if (rt->type == P_IDLE)
-		return "HUP";
-	switch (rt->proto) {
-	case 'S':
-		return "SLIP";
-	case 'P':
-		return "PPP";
-	}
-	return "shell";
-}	 
-
 /*
  *	Find name of NAS
  */
